@@ -350,7 +350,11 @@ class MindsDBLexer(Lexer):
     def ignore_newline(self, t):
         self.lineno += len(t.value)
 
-    @_(r'@(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`))')
+    @_(r'@[a-zA-Z_.$]{1}[a-zA-Z_.$\d]+',
+       r"@'[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^']*'",
+       r"@`[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^`]*`",
+       r'@"[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^"]*"'
+       )
     def VARIABLE(self, t):
         t.value = t.value.lstrip('@')
 
@@ -362,7 +366,11 @@ class MindsDBLexer(Lexer):
             t.value = t.value.strip('`')
         return t
 
-    @_(r'@@(?:([a-zA-Z_$0-9]*[a-zA-Z_$]+[a-zA-Z_$0-9]*)|(?:`([^`]+)`))')
+    @_(r'@@[a-zA-Z_.$]{1}[a-zA-Z_.$\d]+',
+       r"@@'[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^']*'",
+       r"@@`[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^`]*`",
+       r'@@"[a-zA-Z_.$]{1}[a-zA-Z_.$\d][^"]*"'
+       )
     def SYSTEM_VARIABLE(self, t):
         t.value = t.value.lstrip('@')
 
